#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 binary-parser
version:              0.5.7.7
visibility:           public
id:                   binary-parser-0.5.7.7-FEDXreFZOLGGgm6mkIc6N7
key:                  binary-parser-0.5.7.7-FEDXreFZOLGGgm6mkIc6N7
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/binary-parser
synopsis:
    An efficient but limited parser API specialised to bytestrings

category:             Parser, Binary
abi:                  831c6273b83ea6cca05bb3aa408b8457
exposed:              True
exposed-modules:      BinaryParser
hidden-modules:       BinaryParser.Prelude
import-dirs:          /usr/lib/ghc-9.6.6/site-local/binary-parser-0.5.7.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/binary-parser-0.5.7.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/binary-parser-0.5.7.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-binary-parser
hs-libraries:         HSbinary-parser-0.5.7.7-FEDXreFZOLGGgm6mkIc6N7
depends:
    base-4.18.2.1 bytestring-0.11.5.3 mtl-2.3.1 text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-binary-parser/html/binary-parser.haddock

haddock-html:         /usr/share/doc/haskell-binary-parser/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

